"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, export_task_id: str) -> None:
    r"""
    **Autogenerated function**

    Cancels an active export task. The request removes all artifacts of the export, including any partially-created Amazon S3 objects. If the export task is complete or is in the process of transferring the final disk image, the command fails and returns an error.

    Args:
        export_task_id(str): The ID of the export task. This is the ID returned by CreateInstanceExportTask.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.export.task.cancel(ctx, export_task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.export.task.cancel export_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_export_task",
        op_kwargs={"ExportTaskId": export_task_id},
    )


async def describe_all(
    hub, ctx, export_task_ids: List = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified export instance tasks or all of your export instance tasks.

    Args:
        export_task_ids(List, optional): The export task IDs. Defaults to None.
        filters(List, optional): the filters for the export tasks. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.export.task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.export.task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_export_tasks",
        op_kwargs={"ExportTaskIds": export_task_ids, "Filters": filters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, access_token: str, device_key: str, device_remembered_status: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the device status.

    Args:
        access_token(str): The access token.
        device_key(str): The device key.
        device_remembered_status(str, optional): The status of whether a device is remembered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.device.status.update(
                ctx, access_token=value, device_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.device.status.update access_token=value, device_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_device_status",
        op_kwargs={
            "AccessToken": access_token,
            "DeviceKey": device_key,
            "DeviceRememberedStatus": device_remembered_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    fleet_arn: str,
    domain_name: str,
    acm_certificate_arn: str,
    display_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Specifies a domain to be associated to Amazon WorkLink.

    Args:
        fleet_arn(str): The Amazon Resource Name (ARN) of the fleet.
        domain_name(str): The fully qualified domain name (FQDN).
        display_name(str, optional): The name to display. Defaults to None.
        acm_certificate_arn(str): The ARN of an issued ACM certificate that is valid for the domain being associated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.init.associate(
                ctx, fleet_arn=value, domain_name=value, acm_certificate_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.init.associate fleet_arn=value, domain_name=value, acm_certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="associate_domain",
        op_kwargs={
            "FleetArn": fleet_arn,
            "DomainName": domain_name,
            "DisplayName": display_name,
            "AcmCertificateArn": acm_certificate_arn,
        },
    )


async def describe(hub, ctx, fleet_arn: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the domain.

    Args:
        fleet_arn(str): The ARN of the fleet.
        domain_name(str): The name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.init.describe(
                ctx, fleet_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.init.describe fleet_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_domain",
        op_kwargs={"FleetArn": fleet_arn, "DomainName": domain_name},
    )


async def disassociate(hub, ctx, fleet_arn: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a domain from Amazon WorkLink. End users lose the ability to access the domain with Amazon WorkLink.

    Args:
        fleet_arn(str): The ARN of the fleet.
        domain_name(str): The name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.init.disassociate(
                ctx, fleet_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.init.disassociate fleet_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="disassociate_domain",
        op_kwargs={"FleetArn": fleet_arn, "DomainName": domain_name},
    )


async def list_all(
    hub, ctx, fleet_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of domains associated to a specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        next_token(str, optional): The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        max_results(int, optional): The maximum number of results to be included in the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.init.list_all(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.init.list_all fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="list_domains",
        op_kwargs={
            "FleetArn": fleet_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    device_fleet_name: str,
    output_config: Dict,
    role_arn: str = None,
    description: str = None,
    tags: List = None,
    enable_iot_role_alias: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates a device fleet.

    Args:
        device_fleet_name(str): The name of the fleet that the device belongs to.
        role_arn(str, optional): The Amazon Resource Name (ARN) that has access to Amazon Web Services Internet of Things (IoT). Defaults to None.
        description(str, optional): A description of the fleet. Defaults to None.
        output_config(Dict): The output configuration for storing sample data collected by the fleet.
        tags(List, optional): Creates tags for the specified fleet. Defaults to None.
        enable_iot_role_alias(bool, optional): Whether to create an Amazon Web Services IoT Role Alias during device fleet creation. The name of the role alias generated will match this pattern: "SageMakerEdge-{DeviceFleetName}". For example, if your device fleet is called "demo-fleet", the name of the role alias will be "SageMakerEdge-demo-fleet". Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.init.create(
                ctx, device_fleet_name=value, output_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.init.create device_fleet_name=value, output_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_device_fleet",
        op_kwargs={
            "DeviceFleetName": device_fleet_name,
            "RoleArn": role_arn,
            "Description": description,
            "OutputConfig": output_config,
            "Tags": tags,
            "EnableIotRoleAlias": enable_iot_role_alias,
        },
    )


async def delete(hub, ctx, device_fleet_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a fleet.

    Args:
        device_fleet_name(str): The name of the fleet to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.init.delete(ctx, device_fleet_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.init.delete device_fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_device_fleet",
        op_kwargs={"DeviceFleetName": device_fleet_name},
    )


async def describe(hub, ctx, device_fleet_name: str) -> Dict:
    r"""
    **Autogenerated function**

    A description of the fleet the device belongs to.

    Args:
        device_fleet_name(str): The name of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.init.describe(
                ctx, device_fleet_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.init.describe device_fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_device_fleet",
        op_kwargs={"DeviceFleetName": device_fleet_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of devices in the fleet.

    Args:
        next_token(str, optional): The response from the last list when returning a list large enough to need tokening. Defaults to None.
        max_results(int, optional): The maximum number of results to select. Defaults to None.
        creation_time_after(str, optional): Filter fleets where packaging job was created after specified time. Defaults to None.
        creation_time_before(str, optional): Filter fleets where the edge packaging job was created before specified time. Defaults to None.
        last_modified_time_after(str, optional): Select fleets where the job was updated after X. Defaults to None.
        last_modified_time_before(str, optional): Select fleets where the job was updated before X. Defaults to None.
        name_contains(str, optional): Filter for fleets containing this name in their fleet device name. Defaults to None.
        sort_by(str, optional): The column to sort by. Defaults to None.
        sort_order(str, optional): What direction to sort in. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_device_fleets",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def update(
    hub,
    ctx,
    device_fleet_name: str,
    output_config: Dict,
    role_arn: str = None,
    description: str = None,
    enable_iot_role_alias: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a fleet of devices.

    Args:
        device_fleet_name(str): The name of the fleet.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the device. Defaults to None.
        description(str, optional): Description of the fleet. Defaults to None.
        output_config(Dict): Output configuration for storing sample data collected by the fleet.
        enable_iot_role_alias(bool, optional): Whether to create an Amazon Web Services IoT Role Alias during device fleet creation. The name of the role alias generated will match this pattern: "SageMakerEdge-{DeviceFleetName}". For example, if your device fleet is called "demo-fleet", the name of the role alias will be "SageMakerEdge-demo-fleet". Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.init.update(
                ctx, device_fleet_name=value, output_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.init.update device_fleet_name=value, output_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_device_fleet",
        op_kwargs={
            "DeviceFleetName": device_fleet_name,
            "RoleArn": role_arn,
            "Description": description,
            "OutputConfig": output_config,
            "EnableIotRoleAlias": enable_iot_role_alias,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    provisioned_product_id: str,
    service_action_id: str,
    accept_language: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.

    Args:
        provisioned_product_id(str): The identifier of the provisioned product.
        service_action_id(str): The self-service action identifier.
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.service_action.execution_parameter.describe_all(
                ctx, provisioned_product_id=value, service_action_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.service_action.execution_parameter.describe_all provisioned_product_id=value, service_action_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_service_action_execution_parameters",
        op_kwargs={
            "ProvisionedProductId": provisioned_product_id,
            "ServiceActionId": service_action_id,
            "AcceptLanguage": accept_language,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    labeling_job_name: str,
    label_attribute_name: str,
    input_config: Dict,
    output_config: Dict,
    role_arn: str,
    human_task_config: Dict,
    label_category_config_s3_uri: str = None,
    stopping_conditions: Dict = None,
    labeling_job_algorithms_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job that uses workers to label the data objects in your input dataset. You can use the labeled data to train machine learning models.  You can select your workforce from one of three providers:   A private workforce that you create. It can include employees, contractors, and outside experts. Use a private workforce when want the data to stay within your organization or when a specific set of skills is required.   One or more vendors that you select from the Amazon Web Services Marketplace. Vendors provide expertise in specific areas.    The Amazon Mechanical Turk workforce. This is the largest workforce, but it should only be used for public data or data that has been stripped of any personally identifiable information.   You can also use automated data labeling to reduce the number of data objects that need to be labeled by a human. Automated data labeling uses active learning to determine if a data object can be labeled by machine or if it needs to be sent to a human worker. For more information, see Using Automated Data Labeling. The data objects to be labeled are contained in an Amazon S3 bucket. You create a manifest file that describes the location of each object. For more information, see Using Input and Output Data. The output can be used as the manifest file for another labeling job or as training data for your machine learning models. You can use this operation to create a static labeling job or a streaming labeling job. A static labeling job stops if all data objects in the input manifest file identified in ManifestS3Uri have been labeled. A streaming labeling job runs perpetually until it is manually stopped, or remains idle for 10 days. You can send new data objects to an active (InProgress) streaming labeling job in real time. To learn how to create a static labeling job, see Create a Labeling Job (API)  in the Amazon SageMaker Developer Guide. To learn how to create a streaming labeling job, see Create a Streaming Labeling Job.

    Args:
        labeling_job_name(str): The name of the labeling job. This name is used to identify the job in a list of labeling jobs. Labeling job names must be unique within an Amazon Web Services account and region. LabelingJobName is not case sensitive. For example, Example-job and example-job are considered the same labeling job name by Ground Truth.
        label_attribute_name(str): The attribute name to use for the label in the output manifest file. This is the key for the key/value pair formed with the label that a worker assigns to the object. The LabelAttributeName must meet the following requirements.   The name can't end with "-metadata".    If you are using one of the following built-in task types, the attribute name must end with "-ref". If the task type you are using is not listed below, the attribute name must not end with "-ref".   Image semantic segmentation (SemanticSegmentation), and adjustment (AdjustmentSemanticSegmentation) and verification (VerificationSemanticSegmentation) labeling jobs for this task type.   Video frame object detection (VideoObjectDetection), and adjustment and verification (AdjustmentVideoObjectDetection) labeling jobs for this task type.   Video frame object tracking (VideoObjectTracking), and adjustment and verification (AdjustmentVideoObjectTracking) labeling jobs for this task type.   3D point cloud semantic segmentation (3DPointCloudSemanticSegmentation), and adjustment and verification (Adjustment3DPointCloudSemanticSegmentation) labeling jobs for this task type.    3D point cloud object tracking (3DPointCloudObjectTracking), and adjustment and verification (Adjustment3DPointCloudObjectTracking) labeling jobs for this task type.        If you are creating an adjustment or verification labeling job, you must use a different LabelAttributeName than the one used in the original labeling job. The original labeling job is the Ground Truth labeling job that produced the labels that you want verified or adjusted. To learn more about adjustment and verification labeling jobs, see Verify and Adjust Labels. .
        input_config(Dict): Input data for the labeling job, such as the Amazon S3 location of the data objects and the location of the manifest file that describes the data objects. You must specify at least one of the following: S3DataSource or SnsDataSource.    Use SnsDataSource to specify an SNS input topic for a streaming labeling job. If you do not specify and SNS input topic ARN, Ground Truth will create a one-time labeling job that stops after all data objects in the input manifest file have been labeled.   Use S3DataSource to specify an input manifest file for both streaming and one-time labeling jobs. Adding an S3DataSource is optional if you use SnsDataSource to create a streaming labeling job.   If you use the Amazon Mechanical Turk workforce, your input data should not include confidential information, personal information or protected health information. Use ContentClassifiers to specify that your data is free of personally identifiable information and adult content.
        output_config(Dict): The location of the output data and the Amazon Web Services Key Management Service key ID for the key used to encrypt the output data, if any.
        role_arn(str): The Amazon Resource Number (ARN) that Amazon SageMaker assumes to perform tasks on your behalf during data labeling. You must grant this role the necessary permissions so that Amazon SageMaker can successfully complete data labeling.
        label_category_config_s3_uri(str, optional): The S3 URI of the file, referred to as a label category configuration file, that defines the categories used to label the data objects. For 3D point cloud and video frame task types, you can add label category attributes and frame attributes to your label category configuration file. To learn how, see Create a Labeling Category Configuration File for 3D Point Cloud Labeling Jobs.  For all other built-in task types and custom tasks, your label category configuration file must be a JSON file in the following format. Identify the labels you want to use by replacing label_1, label_2,...,label_n with your label categories.  {    "document-version": "2018-11-28",   "labels": [{"label": "label_1"},{"label": "label_2"},...{"label": "label_n"}]   }  Note the following about the label category configuration file:   For image classification and text classification (single and multi-label) you must specify at least two label categories. For all other task types, the minimum number of label categories required is one.    Each label category must be unique, you cannot specify duplicate label categories.   If you create a 3D point cloud or video frame adjustment or verification labeling job, you must include auditLabelAttributeName in the label category configuration. Use this parameter to enter the  LabelAttributeName  of the labeling job you want to adjust or verify annotations of.  . Defaults to None.
        stopping_conditions(Dict, optional): A set of conditions for stopping the labeling job. If any of the conditions are met, the job is automatically stopped. You can use these conditions to control the cost of data labeling. Defaults to None.
        labeling_job_algorithms_config(Dict, optional): Configures the information required to perform automated data labeling. Defaults to None.
        human_task_config(Dict): Configures the labeling task and how it is presented to workers; including, but not limited to price, keywords, and batch size (task count).
        tags(List, optional): An array of key/value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.labeling_job.create(
                ctx,
                labeling_job_name=value,
                label_attribute_name=value,
                input_config=value,
                output_config=value,
                role_arn=value,
                human_task_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.labeling_job.create labeling_job_name=value, label_attribute_name=value, input_config=value, output_config=value, role_arn=value, human_task_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_labeling_job",
        op_kwargs={
            "LabelingJobName": labeling_job_name,
            "LabelAttributeName": label_attribute_name,
            "InputConfig": input_config,
            "OutputConfig": output_config,
            "RoleArn": role_arn,
            "LabelCategoryConfigS3Uri": label_category_config_s3_uri,
            "StoppingConditions": stopping_conditions,
            "LabelingJobAlgorithmsConfig": labeling_job_algorithms_config,
            "HumanTaskConfig": human_task_config,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, labeling_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a labeling job.

    Args:
        labeling_job_name(str): The name of the labeling job to return information for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.labeling_job.describe(ctx, labeling_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.labeling_job.describe labeling_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_labeling_job",
        op_kwargs={"LabelingJobName": labeling_job_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    max_results: int = None,
    next_token: str = None,
    name_contains: str = None,
    sort_by: str = None,
    sort_order: str = None,
    status_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of labeling jobs.

    Args:
        creation_time_after(str, optional): A filter that returns only labeling jobs created after the specified time (timestamp). Defaults to None.
        creation_time_before(str, optional): A filter that returns only labeling jobs created before the specified time (timestamp). Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only labeling jobs modified after the specified time (timestamp). Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only labeling jobs modified before the specified time (timestamp). Defaults to None.
        max_results(int, optional): The maximum number of labeling jobs to return in each page of the response. Defaults to None.
        next_token(str, optional): If the result of the previous ListLabelingJobs request was truncated, the response includes a NextToken. To retrieve the next set of labeling jobs, use the token in the next request. Defaults to None.
        name_contains(str, optional): A string in the labeling job name. This filter returns only labeling jobs whose name contains the specified string. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.
        status_equals(str, optional): A filter that retrieves only labeling jobs with a specific status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.labeling_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.labeling_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_labeling_jobs",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "MaxResults": max_results,
            "NextToken": next_token,
            "NameContains": name_contains,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "StatusEquals": status_equals,
        },
    )


async def stop(hub, ctx, labeling_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a running labeling job. A job that is stopped cannot be restarted. Any results obtained before the job is stopped are placed in the Amazon S3 output bucket.

    Args:
        labeling_job_name(str): The name of the labeling job to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.labeling_job.stop(ctx, labeling_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.labeling_job.stop labeling_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_labeling_job",
        op_kwargs={"LabelingJobName": labeling_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    source_db_instance_arn: str,
    backup_retention_period: int = None,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables replication of automated backups to a different Amazon Web Services Region. For more information, see  Replicating Automated Backups to Another Amazon Web Services Region in the Amazon RDS User Guide.

    Args:
        source_db_instance_arn(str): The Amazon Resource Name (ARN) of the source DB instance for the replicated automated backups, for example, arn:aws:rds:us-west-2:123456789012:db:mydatabase.
        backup_retention_period(int, optional): The retention period for the replicated automated backups. Defaults to None.
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier for encryption of the replicated automated backups. The KMS key ID is the Amazon Resource Name (ARN) for the KMS encryption key in the destination Amazon Web Services Region, for example, arn:aws:kms:us-east-1:123456789012:key/AKIAIOSFODNN7EXAMPLE. Defaults to None.
        pre_signed_url(str, optional): A URL that contains a Signature Version 4 signed request for the StartDBInstanceAutomatedBackupsReplication action to be called in the Amazon Web Services Region of the source DB instance. The presigned URL must be a valid request for the StartDBInstanceAutomatedBackupsReplication API action that can be executed in the Amazon Web Services Region that contains the source DB instance. Defaults to None.
        source_region(str, optional): The ID of the region that contains the source for the db instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.automated_backup.replication.start(
                ctx, source_db_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.automated_backup.replication.start source_db_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="start_db_instance_automated_backups_replication",
        op_kwargs={
            "SourceDBInstanceArn": source_db_instance_arn,
            "BackupRetentionPeriod": backup_retention_period,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "SourceRegion": source_region,
        },
    )


async def stop(hub, ctx, source_db_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops automated backup replication for a DB instance. For more information, see  Replicating Automated Backups to Another Amazon Web Services Region in the Amazon RDS User Guide.

    Args:
        source_db_instance_arn(str): The Amazon Resource Name (ARN) of the source DB instance for which to stop replicating automated backups, for example, arn:aws:rds:us-west-2:123456789012:db:mydatabase.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.automated_backup.replication.stop(
                ctx, source_db_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.automated_backup.replication.stop source_db_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="stop_db_instance_automated_backups_replication",
        op_kwargs={"SourceDBInstanceArn": source_db_instance_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the policy for the application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.policy.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.policy.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="get_application_policy",
        op_kwargs={"ApplicationId": application_id},
    )


async def put(hub, ctx, application_id: str, statements: List) -> Dict:
    r"""
    **Autogenerated function**

    Sets the permission policy for an application. For the list of actions supported for this operation, see
     Application
     Permissions
     .

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        statements(List): An array of policy statements applied to the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.policy.put(
                ctx, application_id=value, statements=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.policy.put application_id=value, statements=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="put_application_policy",
        op_kwargs={"ApplicationId": application_id, "Statements": statements},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def recognize(hub, ctx, image: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of celebrities recognized in the input image. For more information, see Recognizing Celebrities in the Amazon Rekognition Developer Guide.   RecognizeCelebrities returns the 64 largest faces in the image. It lists recognized celebrities in the CelebrityFaces array and unrecognized faces in the UnrecognizedFaces array. RecognizeCelebrities doesn't return celebrities whose faces aren't among the largest 64 faces in the image. For each celebrity recognized, RecognizeCelebrities returns a Celebrity object. The Celebrity object contains the celebrity name, ID, URL links to additional information, match confidence, and a ComparedFace object that you can use to locate the celebrity's face on the image. Amazon Rekognition doesn't retain information about which images a celebrity has been recognized in. Your application must store this information and use the Celebrity ID property as a unique identifier for the celebrity. If you don't store the celebrity name or additional information URLs returned by RecognizeCelebrities, you will need the ID to identify the celebrity in a call to the GetCelebrityInfo operation. You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.  For an example, see Recognizing Celebrities in an Image in the Amazon Rekognition Developer Guide. This operation requires permissions to perform the rekognition:RecognizeCelebrities operation.

    Args:
        image(Dict): The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.celebrity.init.recognize(ctx, image=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.celebrity.init.recognize image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="recognize_celebrities",
        op_kwargs={"Image": image},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    function_name: str,
    zip_file: bytes = None,
    s3_bucket: str = None,
    s3_key: str = None,
    s3_object_version: str = None,
    image_uri: str = None,
    publish: bool = None,
    dry_run: bool = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Lambda function's code. If code signing is enabled for the function, the code package must be signed by a trusted publisher. For more information, see Configuring code signing. The function's code is locked when you publish a version. You can't modify the code of a published version, only the unpublished version.  For a function defined as a container image, Lambda resolves the image tag to an image digest. In Amazon ECR, if you update the image tag to a new image, Lambda does not automatically update the function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        zip_file(bytes, optional): The base64-encoded contents of the deployment package. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you. Defaults to None.
        s3_bucket(str, optional): An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account. Defaults to None.
        s3_key(str, optional): The Amazon S3 key of the deployment package. Defaults to None.
        s3_object_version(str, optional): For versioned objects, the version of the deployment package object to use. Defaults to None.
        image_uri(str, optional): URI of a container image in the Amazon ECR registry. Defaults to None.
        publish(bool, optional): Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately. Defaults to None.
        dry_run(bool, optional): Set to true to validate the request parameters and access permissions without modifying the function code. Defaults to None.
        revision_id(str, optional): Only update the function if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.code.init.update(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.code.init.update function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="update_function_code",
        op_kwargs={
            "FunctionName": function_name,
            "ZipFile": zip_file,
            "S3Bucket": s3_bucket,
            "S3Key": s3_key,
            "S3ObjectVersion": s3_object_version,
            "ImageUri": image_uri,
            "Publish": publish,
            "DryRun": dry_run,
            "RevisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    cluster_identifier: str,
    snapshot_identifier: str,
    snapshot_cluster_identifier: str = None,
    port: int = None,
    availability_zone: str = None,
    allow_version_upgrade: bool = None,
    cluster_subnet_group_name: str = None,
    publicly_accessible: bool = None,
    owner_account: str = None,
    hsm_client_certificate_identifier: str = None,
    hsm_configuration_identifier: str = None,
    elastic_ip: str = None,
    cluster_parameter_group_name: str = None,
    cluster_security_groups: List = None,
    vpc_security_group_ids: List = None,
    preferred_maintenance_window: str = None,
    automated_snapshot_retention_period: int = None,
    manual_snapshot_retention_period: int = None,
    kms_key_id: str = None,
    node_type: str = None,
    enhanced_vpc_routing: bool = None,
    additional_info: str = None,
    iam_roles: List = None,
    maintenance_track_name: str = None,
    snapshot_schedule_identifier: str = None,
    number_of_nodes: int = None,
    availability_zone_relocation: bool = None,
    aqua_configuration_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cluster from a snapshot. By default, Amazon Redshift creates the resulting cluster with the same configuration as the original cluster from which the snapshot was created, except that the new cluster is created with the default cluster security and parameter groups. After Amazon Redshift creates the cluster, you can use the ModifyCluster API to associate a different security group and different parameter group with the restored cluster. If you are using a DS node type, you can also choose to change to another DS node type of the same size during restore. If you restore a cluster into a VPC, you must provide a cluster subnet group where you want the cluster restored.  For more information about working with snapshots, go to Amazon Redshift Snapshots in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_identifier(str): The identifier of the cluster that will be created from restoring the snapshot. Constraints:   Must contain from 1 to 63 alphanumeric characters or hyphens.   Alphabetic characters must be lowercase.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Must be unique for all clusters within an Amazon Web Services account.  .
        snapshot_identifier(str): The name of the snapshot from which to create the new cluster. This parameter isn't case sensitive. Example: my-snapshot-id .
        snapshot_cluster_identifier(str, optional): The name of the cluster the source snapshot was created from. This parameter is required if your IAM user has a policy containing a snapshot resource element that specifies anything other than * for the cluster name. Defaults to None.
        port(int, optional): The port number on which the cluster accepts connections. Default: The same port as the original cluster. Constraints: Must be between 1115 and 65535. Defaults to None.
        availability_zone(str, optional): The Amazon EC2 Availability Zone in which to restore the cluster. Default: A random, system-chosen Availability Zone. Example: us-east-2a . Defaults to None.
        allow_version_upgrade(bool, optional): If true, major version upgrades can be applied during the maintenance window to the Amazon Redshift engine that is running on the cluster.  Default: true . Defaults to None.
        cluster_subnet_group_name(str, optional): The name of the subnet group where you want to cluster restored. A snapshot of cluster in VPC can be restored only in VPC. Therefore, you must provide subnet group name where you want the cluster restored. Defaults to None.
        publicly_accessible(bool, optional): If true, the cluster can be accessed from a public network. . Defaults to None.
        owner_account(str, optional): The Amazon Web Services account used to create or copy the snapshot. Required if you are restoring a snapshot you do not own, optional if you own the snapshot. Defaults to None.
        hsm_client_certificate_identifier(str, optional): Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM. Defaults to None.
        hsm_configuration_identifier(str, optional): Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM. Defaults to None.
        elastic_ip(str, optional): The elastic IP (EIP) address for the cluster. Defaults to None.
        cluster_parameter_group_name(str, optional): The name of the parameter group to be associated with this cluster. Default: The default Amazon Redshift cluster parameter group. For information about the default parameter group, go to Working with Amazon Redshift Parameter Groups. Constraints:   Must be 1 to 255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        cluster_security_groups(List, optional): A list of security groups to be associated with this cluster. Default: The default cluster security group for Amazon Redshift. Cluster security groups only apply to clusters outside of VPCs. Defaults to None.
        vpc_security_group_ids(List, optional): A list of Virtual Private Cloud (VPC) security groups to be associated with the cluster. Default: The default VPC security group is associated with the cluster. VPC security groups only apply to clusters in VPCs. Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which automated cluster maintenance can occur.  Format: ddd:hh24:mi-ddd:hh24:mi   Default: The value selected for the cluster from which the snapshot was taken. For more information about the time blocks for each region, see Maintenance Windows in Amazon Redshift Cluster Management Guide.  Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Minimum 30-minute window. Defaults to None.
        automated_snapshot_retention_period(int, optional): The number of days that automated snapshots are retained. If the value is 0, automated snapshots are disabled. Even if automated snapshots are disabled, you can still create manual snapshots when you want with CreateClusterSnapshot.  You can't disable automated snapshots for RA3 node types. Set the automated retention period from 1-35 days. Default: The value selected for the cluster from which the snapshot was taken. Constraints: Must be a value from 0 to 35. Defaults to None.
        manual_snapshot_retention_period(int, optional): The default number of days to retain a manual snapshot. If the value is -1, the snapshot is retained indefinitely. This setting doesn't change the retention period of existing snapshots. The value must be either -1 or an integer between 1 and 3,653. Defaults to None.
        kms_key_id(str, optional): The Key Management Service (KMS) key ID of the encryption key that you want to use to encrypt data in the cluster that you restore from a shared snapshot. Defaults to None.
        node_type(str, optional): The node type that the restored cluster will be provisioned with. Default: The node type of the cluster from which the snapshot was taken. You can modify this if you are using any DS node type. In that case, you can choose to restore into another DS node type of the same size. For example, you can restore ds1.8xlarge into ds2.8xlarge, or ds1.xlarge into ds2.xlarge. If you have a DC instance type, you must restore into that same instance type and size. In other words, you can only restore a dc1.large instance type into another dc1.large instance type or dc2.large instance type. You can't restore dc1.8xlarge to dc2.8xlarge. First restore to a dc1.8xlarge cluster, then resize to a dc2.8large cluster. For more information about node types, see  About Clusters and Nodes in the Amazon Redshift Cluster Management Guide. . Defaults to None.
        enhanced_vpc_routing(bool, optional): An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide. If this option is true, enhanced VPC routing is enabled.  Default: false. Defaults to None.
        additional_info(str, optional): Reserved. Defaults to None.
        iam_roles(List, optional): A list of Identity and Access Management (IAM) roles that can be used by the cluster to access other Amazon Web Services services. You must supply the IAM roles in their Amazon Resource Name (ARN) format. You can supply up to 10 IAM roles in a single request. A cluster can have up to 10 IAM roles associated at any time. Defaults to None.
        maintenance_track_name(str, optional): The name of the maintenance track for the restored cluster. When you take a snapshot, the snapshot inherits the MaintenanceTrack value from the cluster. The snapshot might be on a different track than the cluster that was the source for the snapshot. For example, suppose that you take a snapshot of a cluster that is on the current track and then change the cluster to be on the trailing track. In this case, the snapshot and the source cluster are on different tracks. Defaults to None.
        snapshot_schedule_identifier(str, optional): A unique identifier for the snapshot schedule. Defaults to None.
        number_of_nodes(int, optional): The number of nodes specified when provisioning the restored cluster. Defaults to None.
        availability_zone_relocation(bool, optional): The option to enable relocation for an Amazon Redshift cluster between Availability Zones after the cluster is restored. Defaults to None.
        aqua_configuration_status(str, optional): The value represents how the cluster is configured to use AQUA (Advanced Query Accelerator) after the cluster is restored. Possible values include the following.   enabled - Use AQUA if it is available for the current Amazon Web Services Region and Amazon Redshift node type.   disabled - Don't use AQUA.    auto - Amazon Redshift determines whether to use AQUA.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.from_cluster_snapshot.restore(
                ctx, cluster_identifier=value, snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.from_cluster_snapshot.restore cluster_identifier=value, snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="restore_from_cluster_snapshot",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "SnapshotClusterIdentifier": snapshot_cluster_identifier,
            "Port": port,
            "AvailabilityZone": availability_zone,
            "AllowVersionUpgrade": allow_version_upgrade,
            "ClusterSubnetGroupName": cluster_subnet_group_name,
            "PubliclyAccessible": publicly_accessible,
            "OwnerAccount": owner_account,
            "HsmClientCertificateIdentifier": hsm_client_certificate_identifier,
            "HsmConfigurationIdentifier": hsm_configuration_identifier,
            "ElasticIp": elastic_ip,
            "ClusterParameterGroupName": cluster_parameter_group_name,
            "ClusterSecurityGroups": cluster_security_groups,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "AutomatedSnapshotRetentionPeriod": automated_snapshot_retention_period,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
            "KmsKeyId": kms_key_id,
            "NodeType": node_type,
            "EnhancedVpcRouting": enhanced_vpc_routing,
            "AdditionalInfo": additional_info,
            "IamRoles": iam_roles,
            "MaintenanceTrackName": maintenance_track_name,
            "SnapshotScheduleIdentifier": snapshot_schedule_identifier,
            "NumberOfNodes": number_of_nodes,
            "AvailabilityZoneRelocation": availability_zone_relocation,
            "AquaConfigurationStatus": aqua_configuration_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_backup_id: str,
    client_request_token: str = None,
    source_region: str = None,
    kms_key_id: str = None,
    copy_tags: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies an existing backup within the same AWS account to another Region (cross-Region copy) or within the same Region (in-Region copy). You can have up to five backup copy requests in progress to a single destination Region per account. You can use cross-Region backup copies for cross-region disaster recovery. You periodically take backups and copy them to another Region so that in the event of a disaster in the primary Region, you can restore from backup and recover availability quickly in the other Region. You can make cross-Region copies only within your AWS partition.  You can also use backup copies to clone your file data set to another Region or within the same Region. You can use the SourceRegion parameter to specify the AWS Region from which the backup will be copied. For example, if you make the call from the us-west-1 Region and want to copy a backup from the us-east-2 Region, you specify us-east-2 in the SourceRegion parameter to make a cross-Region copy. If you don't specify a Region, the backup copy is created in the same Region where the request is sent from (in-Region copy). For more information on creating backup copies, see  Copying backups in the Amazon FSx for Windows User Guide and Copying backups in the Amazon FSx for Lustre User Guide.

    Args:
        client_request_token(str, optional): (Optional) An idempotency token for resource creation, in a string of up to 64 ASCII characters. This token is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        source_backup_id(str): The ID of the source backup. Specifies the ID of the backup that is being copied.
        source_region(str, optional): The source AWS Region of the backup. Specifies the AWS Region from which the backup is being copied. The source and destination Regions must be in the same AWS partition. If you don't specify a Region, it defaults to the Region where the request is sent from (in-Region copy). Defaults to None.
        kms_key_id(str, optional): The ID of the AWS Key Management Service (AWS KMS) key used to encrypt the file system's data for Amazon FSx for Windows File Server file systems and Amazon FSx for Lustre PERSISTENT_1 file systems at rest. In either case, if not specified, the Amazon FSx managed key is used. The Amazon FSx for Lustre SCRATCH_1 and SCRATCH_2 file systems are always encrypted at rest using Amazon FSx managed keys. For more information, see Encrypt in the AWS Key Management Service API Reference. Defaults to None.
        copy_tags(bool, optional): A boolean flag indicating whether tags from the source backup should be copied to the backup copy. This value defaults to false. If you set CopyTags to true and the source backup has existing tags, you can use the Tags parameter to create new tags, provided that the sum of the source backup tags and the new tags doesn't exceed 50. Both sets of tags are merged. If there are tag conflicts (for example, two tags with the same key but different values), the tags created with the Tags parameter take precedence. Defaults to None.
        tags(List, optional): A list of Tag values, with a maximum of 50 elements. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.backup.copy(ctx, source_backup_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.backup.copy source_backup_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="copy_backup",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "SourceBackupId": source_backup_id,
            "SourceRegion": source_region,
            "KmsKeyId": kms_key_id,
            "CopyTags": copy_tags,
            "Tags": tags,
        },
    )


async def create(
    hub, ctx, file_system_id: str, client_request_token: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a backup of an existing Amazon FSx file system. Creating regular backups for your file system is a best practice, enabling you to restore a file system from a backup if an issue arises with the original file system. For Amazon FSx for Lustre file systems, you can create a backup only for file systems with the following configuration:   a Persistent deployment type   is not linked to a data respository.   For more information about backing up Amazon FSx for Lustre file systems, see Working with FSx for Lustre backups. For more information about backing up Amazon FSx for Windows file systems, see Working with FSx for Windows backups. If a backup with the specified client request token exists, and the parameters match, this operation returns the description of the existing backup. If a backup specified client request token exists, and the parameters don't match, this operation returns IncompatibleParameterError. If a backup with the specified client request token doesn't exist, CreateBackup does the following:    Creates a new Amazon FSx backup with an assigned ID, and an initial lifecycle state of CREATING.   Returns the description of the backup.   By using the idempotent operation, you can retry a CreateBackup operation without the risk of creating an extra backup. This approach can be useful when an initial call fails in a way that makes it unclear whether a backup was created. If you use the same client request token and the initial call created a backup, the operation returns a successful result because all the parameters are the same. The CreateBackup operation returns while the backup's lifecycle state is still CREATING. You can check the backup creation status by calling the DescribeBackups operation, which returns the backup state along with other information.

    Args:
        file_system_id(str): The ID of the file system to back up.
        client_request_token(str, optional): (Optional) A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent creation. This string is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        tags(List, optional): (Optional) The tags to apply to the backup at backup creation. The key value of the Name tag appears in the console as the backup name. If you have set CopyTagsToBackups to true, and you specify one or more tags using the CreateBackup action, no existing file system tags are copied from the file system to the backup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.backup.create(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.backup.create file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="create_backup",
        op_kwargs={
            "FileSystemId": file_system_id,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, backup_id: str, client_request_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon FSx backup, deleting its contents. After deletion, the backup no longer exists, and its data is gone. The DeleteBackup call returns instantly. The backup will not show up in later DescribeBackups calls.  The data in a deleted backup is also deleted and can't be recovered by any means.

    Args:
        backup_id(str): The ID of the backup you want to delete.
        client_request_token(str, optional): A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent deletion. This is automatically filled on your behalf when using the AWS CLI or SDK. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.backup.delete(ctx, backup_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.backup.delete backup_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="delete_backup",
        op_kwargs={"BackupId": backup_id, "ClientRequestToken": client_request_token},
    )


async def describe_all(
    hub,
    ctx,
    backup_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of specific Amazon FSx backups, if a BackupIds value is provided for that backup. Otherwise, it returns all backups owned by your AWS account in the AWS Region of the endpoint that you're calling. When retrieving all backups, you can optionally specify the MaxResults parameter to limit the number of backups in a response. If more backups remain, Amazon FSx returns a NextToken value in the response. In this case, send a later request with the NextToken request parameter set to the value of NextToken from the last response. This action is used in an iterative process to retrieve a list of your backups. DescribeBackups is called first without a NextTokenvalue. Then the action continues to be called with the NextToken parameter set to the value of the last NextToken value until a response has no NextToken. When using this action, keep the following in mind:   The implementation might return fewer than MaxResults file system descriptions while still including a NextToken value.   The order of backups returned in the response of one DescribeBackups call and the order of backups returned across the responses of a multi-call iteration is unspecified.

    Args:
        backup_ids(List, optional): IDs of the backups you want to retrieve (String). This overrides any filters. If any IDs are not found, BackupNotFound will be thrown. Defaults to None.
        filters(List, optional): Filters structure. Supported names are file-system-id and backup-type. Defaults to None.
        max_results(int, optional): Maximum number of backups to return in the response (integer). This parameter value must be greater than 0. The number of items that Amazon FSx returns is the minimum of the MaxResults parameter specified in the request and the service's internal maximum number of items per page. Defaults to None.
        next_token(str, optional): Opaque pagination token returned from a previous DescribeBackups operation (String). If a token present, the action continues the list from where the returning call left off. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.backup.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.backup.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="describe_backups",
        op_kwargs={
            "BackupIds": backup_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, meeting_id: str, external_user_id: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new attendee for an active Amazon Chime SDK meeting. For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        external_user_id(str): The Amazon Chime SDK external user ID. An idempotency token. Links the attendee to an identity managed by a builder application.
        tags(List, optional): The tag key-value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.create(
                ctx, meeting_id=value, external_user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.create meeting_id=value, external_user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_attendee",
        op_kwargs={
            "MeetingId": meeting_id,
            "ExternalUserId": external_user_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, meeting_id: str, attendee_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an attendee from the specified Amazon Chime SDK meeting and deletes their JoinToken. Attendees are automatically deleted when a Amazon Chime SDK meeting is deleted. For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        attendee_id(str): The Amazon Chime SDK attendee ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.delete(
                ctx, meeting_id=value, attendee_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.delete meeting_id=value, attendee_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_attendee",
        op_kwargs={"MeetingId": meeting_id, "AttendeeId": attendee_id},
    )


async def get(hub, ctx, meeting_id: str, attendee_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets the Amazon Chime SDK attendee details for a specified meeting ID and attendee ID. For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide .

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        attendee_id(str): The Amazon Chime SDK attendee ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.get(
                ctx, meeting_id=value, attendee_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.get meeting_id=value, attendee_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_attendee",
        op_kwargs={"MeetingId": meeting_id, "AttendeeId": attendee_id},
    )


async def list_all(
    hub, ctx, meeting_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Lists the attendees for the specified Amazon Chime SDK meeting. For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.list_all(ctx, meeting_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.list_all meeting_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_attendees",
        op_kwargs={
            "MeetingId": meeting_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def tag(hub, ctx, meeting_id: str, attendee_id: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Applies the specified tags to the specified Amazon Chime SDK attendee.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        attendee_id(str): The Amazon Chime SDK attendee ID.
        tags(List): The tag key-value pairs.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.tag(
                ctx, meeting_id=value, attendee_id=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.tag meeting_id=value, attendee_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="tag_attendee",
        op_kwargs={"MeetingId": meeting_id, "AttendeeId": attendee_id, "Tags": tags},
    )


async def untag(hub, ctx, meeting_id: str, attendee_id: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Untags the specified tags from the specified Amazon Chime SDK attendee.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        attendee_id(str): The Amazon Chime SDK attendee ID.
        tag_keys(List): The tag keys.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.attendee.init.untag(
                ctx, meeting_id=value, attendee_id=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.attendee.init.untag meeting_id=value, attendee_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="untag_attendee",
        op_kwargs={
            "MeetingId": meeting_id,
            "AttendeeId": attendee_id,
            "TagKeys": tag_keys,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Tag resource to represent a tag.

    Args:
        resource_arn(str): The resource ARN for the tag.
        tags(Dict, optional): The collection of tags. Each tag element is associated with a given resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.resource.tag(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.resource.tag resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Deletes a Tag.

    Args:
        resource_arn(str): The resource ARN for the tag.
        tag_keys(List): The Tag keys to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    app_id: str,
    branch_name: str,
    description: str = None,
    stage: str = None,
    framework: str = None,
    enable_notification: bool = None,
    enable_auto_build: bool = None,
    environment_variables: Dict = None,
    basic_auth_credentials: str = None,
    enable_basic_auth: bool = None,
    enable_performance_mode: bool = None,
    tags: Dict = None,
    build_spec: str = None,
    ttl: str = None,
    display_name: str = None,
    enable_pull_request_preview: bool = None,
    pull_request_environment_name: str = None,
    backend_environment_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new branch for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch. .
        description(str, optional):  The description for the branch. . Defaults to None.
        stage(str, optional):  Describes the current stage for the branch. . Defaults to None.
        framework(str, optional):  The framework for the branch. . Defaults to None.
        enable_notification(bool, optional):  Enables notifications for the branch. . Defaults to None.
        enable_auto_build(bool, optional):  Enables auto building for the branch. . Defaults to None.
        environment_variables(Dict, optional):  The environment variables for the branch. . Defaults to None.
        basic_auth_credentials(str, optional):  The basic authorization credentials for the branch. . Defaults to None.
        enable_basic_auth(bool, optional):  Enables basic authorization for the branch. . Defaults to None.
        enable_performance_mode(bool, optional): Enables performance mode for the branch. Performance mode optimizes for faster hosting performance by keeping content cached at the edge for a longer interval. When performance mode is enabled, hosting configuration or code changes can take up to 10 minutes to roll out. . Defaults to None.
        tags(Dict, optional):  The tag for the branch. . Defaults to None.
        build_spec(str, optional):  The build specification (build spec) for the branch. . Defaults to None.
        ttl(str, optional):  The content Time To Live (TTL) for the website in seconds. . Defaults to None.
        display_name(str, optional):  The display name for a branch. This is used as the default domain prefix. . Defaults to None.
        enable_pull_request_preview(bool, optional):  Enables pull request previews for this branch. . Defaults to None.
        pull_request_environment_name(str, optional):  The Amplify environment name for the pull request. . Defaults to None.
        backend_environment_arn(str, optional):  The Amazon Resource Name (ARN) for a backend environment that is part of an Amplify app. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.branch.create(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.branch.create app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="create_branch",
        op_kwargs={
            "appId": app_id,
            "branchName": branch_name,
            "description": description,
            "stage": stage,
            "framework": framework,
            "enableNotification": enable_notification,
            "enableAutoBuild": enable_auto_build,
            "environmentVariables": environment_variables,
            "basicAuthCredentials": basic_auth_credentials,
            "enableBasicAuth": enable_basic_auth,
            "enablePerformanceMode": enable_performance_mode,
            "tags": tags,
            "buildSpec": build_spec,
            "ttl": ttl,
            "displayName": display_name,
            "enablePullRequestPreview": enable_pull_request_preview,
            "pullRequestEnvironmentName": pull_request_environment_name,
            "backendEnvironmentArn": backend_environment_arn,
        },
    )


async def delete(hub, ctx, app_id: str, branch_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a branch for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.branch.delete(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.branch.delete app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="delete_branch",
        op_kwargs={"appId": app_id, "branchName": branch_name},
    )


async def get(hub, ctx, app_id: str, branch_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a branch for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.branch.get(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.branch.get app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="get_branch",
        op_kwargs={"appId": app_id, "branchName": branch_name},
    )


async def list_all(
    hub, ctx, app_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Lists the branches of an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        next_token(str, optional):  A pagination token. Set to null to start listing branches from the start. If a non-null pagination token is returned in a result, pass its value in here to list more branches. . Defaults to None.
        max_results(int, optional):  The maximum number of records to list in a single response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.branch.list_all(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.branch.list_all app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="list_branches",
        op_kwargs={"appId": app_id, "nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    app_id: str,
    branch_name: str,
    description: str = None,
    framework: str = None,
    stage: str = None,
    enable_notification: bool = None,
    enable_auto_build: bool = None,
    environment_variables: Dict = None,
    basic_auth_credentials: str = None,
    enable_basic_auth: bool = None,
    enable_performance_mode: bool = None,
    build_spec: str = None,
    ttl: str = None,
    display_name: str = None,
    enable_pull_request_preview: bool = None,
    pull_request_environment_name: str = None,
    backend_environment_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a branch for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch. .
        description(str, optional):  The description for the branch. . Defaults to None.
        framework(str, optional):  The framework for the branch. . Defaults to None.
        stage(str, optional):  Describes the current stage for the branch. . Defaults to None.
        enable_notification(bool, optional):  Enables notifications for the branch. . Defaults to None.
        enable_auto_build(bool, optional):  Enables auto building for the branch. . Defaults to None.
        environment_variables(Dict, optional):  The environment variables for the branch. . Defaults to None.
        basic_auth_credentials(str, optional):  The basic authorization credentials for the branch. . Defaults to None.
        enable_basic_auth(bool, optional):  Enables basic authorization for the branch. . Defaults to None.
        enable_performance_mode(bool, optional): Enables performance mode for the branch. Performance mode optimizes for faster hosting performance by keeping content cached at the edge for a longer interval. When performance mode is enabled, hosting configuration or code changes can take up to 10 minutes to roll out. . Defaults to None.
        build_spec(str, optional):  The build specification (build spec) for the branch. . Defaults to None.
        ttl(str, optional):  The content Time to Live (TTL) for the website in seconds. . Defaults to None.
        display_name(str, optional):  The display name for a branch. This is used as the default domain prefix. . Defaults to None.
        enable_pull_request_preview(bool, optional):  Enables pull request previews for this branch. . Defaults to None.
        pull_request_environment_name(str, optional):  The Amplify environment name for the pull request. . Defaults to None.
        backend_environment_arn(str, optional):  The Amazon Resource Name (ARN) for a backend environment that is part of an Amplify app. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.branch.update(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.branch.update app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="update_branch",
        op_kwargs={
            "appId": app_id,
            "branchName": branch_name,
            "description": description,
            "framework": framework,
            "stage": stage,
            "enableNotification": enable_notification,
            "enableAutoBuild": enable_auto_build,
            "environmentVariables": environment_variables,
            "basicAuthCredentials": basic_auth_credentials,
            "enableBasicAuth": enable_basic_auth,
            "enablePerformanceMode": enable_performance_mode,
            "buildSpec": build_spec,
            "ttl": ttl,
            "displayName": display_name,
            "enablePullRequestPreview": enable_pull_request_preview,
            "pullRequestEnvironmentName": pull_request_environment_name,
            "backendEnvironmentArn": backend_environment_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rule_group_name: str,
    type_: str,
    capacity: int,
    rule_group: Dict = None,
    rules: str = None,
    description: str = None,
    tags: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.  You provide your rule group specification in your request using either RuleGroup or Rules.

    Args:
        rule_group_name(str): The descriptive name of the rule group. You can't change the name of a rule group after you create it.
        rule_group(Dict, optional): An object that defines the rule group rules.   You must provide either this rule group setting or a Rules setting, but not both.  . Defaults to None.
        rules(str, optional): A string containing stateful rule group rules specifications in Suricata flat format, with one rule per line. Use this to import your existing Suricata compatible rule groups.   You must provide either this rules setting or a populated RuleGroup setting, but not both.   You can provide your rule group specification in Suricata flat format through this setting when you create or update your rule group. The call response returns a RuleGroup object that Network Firewall has populated from your string. . Defaults to None.
        type_(str): Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules. .
        description(str, optional): A description of the rule group. . Defaults to None.
        capacity(int): The maximum operating resources that this rule group can use. Rule group capacity is fixed at creation. When you update a rule group, you are limited to this capacity. When you reference a rule group from a firewall policy, Network Firewall reserves this capacity for the rule group.  You can retrieve the capacity that would be required for a rule group before you create the rule group by calling CreateRuleGroup with DryRun set to TRUE.   You can't change or exceed this capacity when you update the rule group, so leave room for your rule group to grow.    Capacity for a stateless rule group  For a stateless rule group, the capacity required is the sum of the capacity requirements of the individual rules that you expect to have in the rule group.  To calculate the capacity requirement of a single rule, multiply the capacity requirement values of each of the rule's match settings:   A match setting with no criteria specified has a value of 1.    A match setting with Any specified has a value of 1.    All other match settings have a value equal to the number of elements provided in the setting. For example, a protocol setting ["UDP"] and a source setting ["10.0.0.0/24"] each have a value of 1. A protocol setting ["UDP","TCP"] has a value of 2. A source setting ["10.0.0.0/24","10.0.0.1/24","10.0.0.2/24"] has a value of 3.    A rule with no criteria specified in any of its match settings has a capacity requirement of 1. A rule with protocol setting ["UDP","TCP"], source setting ["10.0.0.0/24","10.0.0.1/24","10.0.0.2/24"], and a single specification or no specification for each of the other match settings has a capacity requirement of 6.   Capacity for a stateful rule group  For a stateful rule group, the minimum capacity required is the number of individual rules that you expect to have in the rule group. .
        tags(List, optional): The key:value pairs to associate with the resource. Defaults to None.
        dry_run(bool, optional): Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.  If set to TRUE, Network Firewall checks whether the request can run successfully, but doesn't actually make the requested changes. The call returns the value that the request would return if you ran it with dry run set to FALSE, but doesn't make additions or changes to your resources. This option allows you to make sure that you have the required permissions to run the request and that your request parameters are valid.  If set to FALSE, Network Firewall makes the requested changes to your resources. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.rule_group.create(
                ctx, rule_group_name=value, type_=value, capacity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.rule_group.create rule_group_name=value, type_=value, capacity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="create_rule_group",
        op_kwargs={
            "RuleGroupName": rule_group_name,
            "RuleGroup": rule_group,
            "Rules": rules,
            "Type": type_,
            "Description": description,
            "Capacity": capacity,
            "Tags": tags,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, rule_group_name: str = None, rule_group_arn: str = None, type_: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified RuleGroup.

    Args:
        rule_group_name(str, optional): The descriptive name of the rule group. You can't change the name of a rule group after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        rule_group_arn(str, optional): The Amazon Resource Name (ARN) of the rule group. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        type_(str, optional): Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.   This setting is required for requests that do not include the RuleGroupARN. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.rule_group.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.rule_group.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="delete_rule_group",
        op_kwargs={
            "RuleGroupName": rule_group_name,
            "RuleGroupArn": rule_group_arn,
            "Type": type_,
        },
    )


async def describe(
    hub, ctx, rule_group_name: str = None, rule_group_arn: str = None, type_: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data objects for the specified rule group.

    Args:
        rule_group_name(str, optional): The descriptive name of the rule group. You can't change the name of a rule group after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        rule_group_arn(str, optional): The Amazon Resource Name (ARN) of the rule group. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        type_(str, optional): Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.   This setting is required for requests that do not include the RuleGroupARN. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.rule_group.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.rule_group.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="describe_rule_group",
        op_kwargs={
            "RuleGroupName": rule_group_name,
            "RuleGroupArn": rule_group_arn,
            "Type": type_,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata for the rule groups that you have defined. Depending on your setting for max results and the number of rule groups, a single call might not return the full list.

    Args:
        next_token(str, optional): When you request a list of objects with a MaxResults setting, if the number of objects that are still available for retrieval exceeds the maximum you requested, Network Firewall returns a NextToken value in the response. To retrieve the next batch of objects, use the token returned from the prior request in your next request. Defaults to None.
        max_results(int, optional): The maximum number of objects that you want Network Firewall to return for this request. If more objects are available, in the response, Network Firewall provides a NextToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.rule_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.rule_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="list_rule_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    update_token: str,
    rule_group_arn: str = None,
    rule_group_name: str = None,
    rule_group: Dict = None,
    rules: str = None,
    type_: str = None,
    description: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.  To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.

    Args:
        update_token(str): A token used for optimistic locking. Network Firewall returns a token to your requests that access the rule group. The token marks the state of the rule group resource at the time of the request.  To make changes to the rule group, you provide the token in your request. Network Firewall uses the token to ensure that the rule group hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the rule group again to get a current copy of it with a current token. Reapply your changes as needed, then try the operation again using the new token. .
        rule_group_arn(str, optional): The Amazon Resource Name (ARN) of the rule group. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        rule_group_name(str, optional): The descriptive name of the rule group. You can't change the name of a rule group after you create it. You must specify the ARN or the name, and you can specify both. . Defaults to None.
        rule_group(Dict, optional): An object that defines the rule group rules.   You must provide either this rule group setting or a Rules setting, but not both.  . Defaults to None.
        rules(str, optional): A string containing stateful rule group rules specifications in Suricata flat format, with one rule per line. Use this to import your existing Suricata compatible rule groups.   You must provide either this rules setting or a populated RuleGroup setting, but not both.   You can provide your rule group specification in Suricata flat format through this setting when you create or update your rule group. The call response returns a RuleGroup object that Network Firewall has populated from your string. . Defaults to None.
        type_(str, optional): Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.   This setting is required for requests that do not include the RuleGroupARN. . Defaults to None.
        description(str, optional): A description of the rule group. . Defaults to None.
        dry_run(bool, optional): Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.  If set to TRUE, Network Firewall checks whether the request can run successfully, but doesn't actually make the requested changes. The call returns the value that the request would return if you ran it with dry run set to FALSE, but doesn't make additions or changes to your resources. This option allows you to make sure that you have the required permissions to run the request and that your request parameters are valid.  If set to FALSE, Network Firewall makes the requested changes to your resources. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.network_firewall.rule_group.update(ctx, update_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.network_firewall.rule_group.update update_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="network-firewall",
        operation="update_rule_group",
        op_kwargs={
            "UpdateToken": update_token,
            "RuleGroupArn": rule_group_arn,
            "RuleGroupName": rule_group_name,
            "RuleGroup": rule_group,
            "Rules": rules,
            "Type": type_,
            "Description": description,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def dissociate(hub, ctx, thing_name: str, entity_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Dissociates a device entity from a concrete thing. The action takes only the type of the entity that you need to dissociate because only one entity of a particular type can be associated with a thing.

    Args:
        thing_name(str): The name of the thing to disassociate.
        entity_type(str): The entity type from which to disassociate the thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.entity.from_thing.dissociate(
                ctx, thing_name=value, entity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.entity.from_thing.dissociate thing_name=value, entity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="dissociate_entity_from_thing",
        op_kwargs={"thingName": thing_name, "entityType": entity_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, app_id: str, branch_name: str, file_map: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a deployment for a manually deployed Amplify app. Manually deployed apps are not connected to a repository.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch, for the job. .
        file_map(Dict, optional):  An optional file map that contains the file name as the key and the file content md5 hash as the value. If this argument is provided, the service will generate a unique upload URL per file. Otherwise, the service will only generate a single upload URL for the zipped files. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.deployment.create(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.deployment.create app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="create_deployment",
        op_kwargs={"appId": app_id, "branchName": branch_name, "fileMap": file_map},
    )


async def start(
    hub, ctx, app_id: str, branch_name: str, job_id: str = None, source_url: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Starts a deployment for a manually deployed app. Manually deployed apps are not connected to a repository.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        branch_name(str):  The name for the branch, for the job. .
        job_id(str, optional):  The job ID for this deployment, generated by the create deployment request. . Defaults to None.
        source_url(str, optional):  The source URL for this deployment, used when calling start deployment without create deployment. The source URL can be any HTTP GET URL that is publicly accessible and downloads a single .zip file. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.deployment.start(ctx, app_id=value, branch_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.deployment.start app_id=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="start_deployment",
        op_kwargs={
            "appId": app_id,
            "branchName": branch_name,
            "jobId": job_id,
            "sourceUrl": source_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def compare(
    hub,
    ctx,
    source_image: Dict,
    target_image: Dict,
    similarity_threshold: float = None,
    quality_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Compares a face in the source input image with each of the 100 largest faces detected in the target input image.   If the source image contains multiple faces, the service detects the largest face and compares it with each face detected in the target image.   CompareFaces uses machine learning algorithms, which are probabilistic. A false negative is an incorrect prediction that a face in the target image has a low similarity confidence score when compared to the face in the source image. To reduce the probability of false negatives, we recommend that you compare the target image against multiple source images. If you plan to use CompareFaces to make a decision that impacts an individual's rights, privacy, or access to services, we recommend that you pass the result to a human for review and further validation before taking action.  You pass the input and target images either as base64-encoded image bytes or as references to images in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes isn't supported. The image must be formatted as a PNG or JPEG file.  In response, the operation returns an array of face matches ordered by similarity score in descending order. For each face match, the response provides a bounding box of the face, facial landmarks, pose details (pitch, role, and yaw), quality (brightness and sharpness), and confidence value (indicating the level of confidence that the bounding box contains a face). The response also provides a similarity score, which indicates how closely the faces match.   By default, only faces with a similarity score of greater than or equal to 80% are returned in the response. You can change this value by specifying the SimilarityThreshold parameter.   CompareFaces also returns an array of faces that don't match the source image. For each face, it returns a bounding box, confidence value, landmarks, pose details, and quality. The response also returns information about the face in the source image, including the bounding box of the face and confidence value. The QualityFilter input parameter allows you to filter out detected faces that don’t meet a required quality bar. The quality bar is based on a variety of common use cases. Use QualityFilter to set the quality bar by specifying LOW, MEDIUM, or HIGH. If you do not want to filter detected faces, specify NONE. The default value is NONE.  If the image doesn't contain Exif metadata, CompareFaces returns orientation information for the source and target images. Use these values to display the images with the correct image orientation. If no faces are detected in the source or target images, CompareFaces returns an InvalidParameterException error.    This is a stateless API operation. That is, data returned by this operation doesn't persist.  For an example, see Comparing Faces in Images in the Amazon Rekognition Developer Guide. This operation requires permissions to perform the rekognition:CompareFaces action.

    Args:
        source_image(Dict): The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        target_image(Dict): The target image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        similarity_threshold(float, optional): The minimum level of confidence in the face matches that a match must meet to be included in the FaceMatches array. Defaults to None.
        quality_filter(str, optional): A filter that specifies a quality bar for how much filtering is done to identify faces. Filtered faces aren't compared. If you specify AUTO, Amazon Rekognition chooses the quality bar. If you specify LOW, MEDIUM, or HIGH, filtering removes all faces that don’t meet the chosen quality bar. The quality bar is based on a variety of common use cases. Low-quality detections can occur for a number of reasons. Some examples are an object that's misidentified as a face, a face that's too blurry, or a face with a pose that's too extreme to use. If you specify NONE, no filtering is performed. The default value is NONE.  To use quality filtering, the collection you are using must be associated with version 3 of the face model or higher. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.compare(
                ctx, source_image=value, target_image=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.compare source_image=value, target_image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="compare_faces",
        op_kwargs={
            "SourceImage": source_image,
            "TargetImage": target_image,
            "SimilarityThreshold": similarity_threshold,
            "QualityFilter": quality_filter,
        },
    )


async def delete_multiple(hub, ctx, collection_id: str, face_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes faces from a collection. You specify a collection ID and an array of face IDs to remove from the collection. This operation requires permissions to perform the rekognition:DeleteFaces action.

    Args:
        collection_id(str): Collection from which to remove the specific faces.
        face_ids(List): An array of face IDs to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.delete_multiple(
                ctx, collection_id=value, face_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.delete_multiple collection_id=value, face_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="delete_faces",
        op_kwargs={"CollectionId": collection_id, "FaceIds": face_ids},
    )


async def detect(hub, ctx, image: Dict, attributes: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Detects faces within an image that is provided as input.  DetectFaces detects the 100 largest faces in the image. For each face detected, the operation returns face details. These details include a bounding box of the face, a confidence value (that the bounding box contains a face), and a fixed set of attributes such as facial landmarks (for example, coordinates of eye and mouth), presence of beard, sunglasses, and so on.  The face-detection algorithm is most effective on frontal faces. For non-frontal or obscured faces, the algorithm might not detect the faces or might detect faces with lower confidence.  You pass the input image either as base64-encoded image bytes or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes is not supported. The image must be either a PNG or JPEG formatted file.   This is a stateless API operation. That is, the operation does not persist any data.  This operation requires permissions to perform the rekognition:DetectFaces action.

    Args:
        image(Dict): The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes is not supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        attributes(List, optional): An array of facial attributes you want to be returned. This can be the default list of attributes or all attributes. If you don't specify a value for Attributes or if you specify ["DEFAULT"], the API returns the following subset of facial attributes: BoundingBox, Confidence, Pose, Quality, and Landmarks. If you provide ["ALL"], all facial attributes are returned, but the operation takes longer to complete. If you provide both, ["ALL", "DEFAULT"], the service uses a logical AND operator to determine which attributes to return (in this case, all attributes). . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.detect(ctx, image=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.detect image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="detect_faces",
        op_kwargs={"Image": image, "Attributes": attributes},
    )


async def index(
    hub,
    ctx,
    collection_id: str,
    image: Dict,
    external_image_id: str = None,
    detection_attributes: List = None,
    max_faces: int = None,
    quality_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Detects faces in the input image and adds them to the specified collection.  Amazon Rekognition doesn't save the actual faces that are detected. Instead, the underlying detection algorithm first detects the faces in the input image. For each face, the algorithm extracts facial features into a feature vector, and stores it in the backend database. Amazon Rekognition uses feature vectors when it performs face match and search operations using the SearchFaces and SearchFacesByImage operations. For more information, see Adding Faces to a Collection in the Amazon Rekognition Developer Guide. To get the number of faces in a collection, call DescribeCollection.  If you're using version 1.0 of the face detection model, IndexFaces indexes the 15 largest faces in the input image. Later versions of the face detection model index the 100 largest faces in the input image.  If you're using version 4 or later of the face model, image orientation information is not returned in the OrientationCorrection field.  To determine which version of the model you're using, call DescribeCollection and supply the collection ID. You can also get the model version from the value of FaceModelVersion in the response from IndexFaces  For more information, see Model Versioning in the Amazon Rekognition Developer Guide. If you provide the optional ExternalImageId for the input image you provided, Amazon Rekognition associates this ID with all faces that it detects. When you call the ListFaces operation, the response returns the external ID. You can use this external image ID to create a client-side index to associate the faces with each image. You can then use the index to find all faces in an image. You can specify the maximum number of faces to index with the MaxFaces input parameter. This is useful when you want to index the largest faces in an image and don't want to index smaller faces, such as those belonging to people standing in the background. The QualityFilter input parameter allows you to filter out detected faces that don’t meet a required quality bar. The quality bar is based on a variety of common use cases. By default, IndexFaces chooses the quality bar that's used to filter faces. You can also explicitly choose the quality bar. Use QualityFilter, to set the quality bar by specifying LOW, MEDIUM, or HIGH. If you do not want to filter detected faces, specify NONE.   To use quality filtering, you need a collection associated with version 3 of the face model or higher. To get the version of the face model associated with a collection, call DescribeCollection.   Information about faces detected in an image, but not indexed, is returned in an array of UnindexedFace objects, UnindexedFaces. Faces aren't indexed for reasons such as:   The number of faces detected exceeds the value of the MaxFaces request parameter.   The face is too small compared to the image dimensions.   The face is too blurry.   The image is too dark.   The face has an extreme pose.   The face doesn’t have enough detail to be suitable for face search.   In response, the IndexFaces operation returns an array of metadata for all detected faces, FaceRecords. This includes:    The bounding box, BoundingBox, of the detected face.    A confidence value, Confidence, which indicates the confidence that the bounding box contains a face.   A face ID, FaceId, assigned by the service for each face that's detected and stored.   An image ID, ImageId, assigned by the service for the input image.   If you request all facial attributes (by using the detectionAttributes parameter), Amazon Rekognition returns detailed facial attributes, such as facial landmarks (for example, location of eye and mouth) and other facial attributes. If you provide the same image, specify the same collection, and use the same external ID in the IndexFaces operation, Amazon Rekognition doesn't save duplicate face metadata.  The input image is passed either as base64-encoded image bytes, or as a reference to an image in an Amazon S3 bucket. If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes isn't supported. The image must be formatted as a PNG or JPEG file.  This operation requires permissions to perform the rekognition:IndexFaces action.

    Args:
        collection_id(str): The ID of an existing collection to which you want to add the faces that are detected in the input images.
        image(Dict): The input image as base64-encoded bytes or an S3 object. If you use the AWS CLI to call Amazon Rekognition operations, passing base64-encoded image bytes isn't supported.  If you are using an AWS SDK to call Amazon Rekognition, you might not need to base64-encode image bytes passed using the Bytes field. For more information, see Images in the Amazon Rekognition developer guide.
        external_image_id(str, optional): The ID you want to assign to all the faces detected in the image. Defaults to None.
        detection_attributes(List, optional): An array of facial attributes that you want to be returned. This can be the default list of attributes or all attributes. If you don't specify a value for Attributes or if you specify ["DEFAULT"], the API returns the following subset of facial attributes: BoundingBox, Confidence, Pose, Quality, and Landmarks. If you provide ["ALL"], all facial attributes are returned, but the operation takes longer to complete. If you provide both, ["ALL", "DEFAULT"], the service uses a logical AND operator to determine which attributes to return (in this case, all attributes). . Defaults to None.
        max_faces(int, optional): The maximum number of faces to index. The value of MaxFaces must be greater than or equal to 1. IndexFaces returns no more than 100 detected faces in an image, even if you specify a larger value for MaxFaces. If IndexFaces detects more faces than the value of MaxFaces, the faces with the lowest quality are filtered out first. If there are still more faces than the value of MaxFaces, the faces with the smallest bounding boxes are filtered out (up to the number that's needed to satisfy the value of MaxFaces). Information about the unindexed faces is available in the UnindexedFaces array.  The faces that are returned by IndexFaces are sorted by the largest face bounding box size to the smallest size, in descending order.  MaxFaces can be used with a collection associated with any version of the face model. Defaults to None.
        quality_filter(str, optional): A filter that specifies a quality bar for how much filtering is done to identify faces. Filtered faces aren't indexed. If you specify AUTO, Amazon Rekognition chooses the quality bar. If you specify LOW, MEDIUM, or HIGH, filtering removes all faces that don’t meet the chosen quality bar. The default value is AUTO. The quality bar is based on a variety of common use cases. Low-quality detections can occur for a number of reasons. Some examples are an object that's misidentified as a face, a face that's too blurry, or a face with a pose that's too extreme to use. If you specify NONE, no filtering is performed.  To use quality filtering, the collection you are using must be associated with version 3 of the face model or higher. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.index(
                ctx, collection_id=value, image=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.index collection_id=value, image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="index_faces",
        op_kwargs={
            "CollectionId": collection_id,
            "Image": image,
            "ExternalImageId": external_image_id,
            "DetectionAttributes": detection_attributes,
            "MaxFaces": max_faces,
            "QualityFilter": quality_filter,
        },
    )


async def list_all(
    hub, ctx, collection_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata for faces in the specified collection. This metadata includes information such as the bounding box coordinates, the confidence (that the bounding box contains a face), and face ID. For an example, see Listing Faces in a Collection in the Amazon Rekognition Developer Guide. This operation requires permissions to perform the rekognition:ListFaces action.

    Args:
        collection_id(str): ID of the collection from which to list the faces.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Rekognition returns a pagination token in the response. You can use this pagination token to retrieve the next set of faces. Defaults to None.
        max_results(int, optional): Maximum number of faces to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.list_all(ctx, collection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.list_all collection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="list_faces",
        op_kwargs={
            "CollectionId": collection_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def search(
    hub,
    ctx,
    collection_id: str,
    face_id: str,
    max_faces: int = None,
    face_match_threshold: float = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For a given input face ID, searches for matching faces in the collection the face belongs to. You get a face ID when you add a face to the collection using the IndexFaces operation. The operation compares the features of the input face with faces in the specified collection.   You can also search faces without indexing faces by using the SearchFacesByImage operation.   The operation response returns an array of faces that match, ordered by similarity score with the highest similarity first. More specifically, it is an array of metadata for each face match that is found. Along with the metadata, the response also includes a confidence value for each face match, indicating the confidence that the specific face matches the input face.  For an example, see Searching for a Face Using Its Face ID in the Amazon Rekognition Developer Guide. This operation requires permissions to perform the rekognition:SearchFaces action.

    Args:
        collection_id(str): ID of the collection the face belongs to.
        face_id(str): ID of a face to find matches for in the collection.
        max_faces(int, optional): Maximum number of faces to return. The operation returns the maximum number of faces with the highest confidence in the match. Defaults to None.
        face_match_threshold(float, optional): Optional value specifying the minimum confidence in the face match to return. For example, don't return any matches where confidence in matches is less than 70%. The default value is 80%. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.face.init.search(
                ctx, collection_id=value, face_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.face.init.search collection_id=value, face_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="search_faces",
        op_kwargs={
            "CollectionId": collection_id,
            "FaceId": face_id,
            "MaxFaces": max_faces,
            "FaceMatchThreshold": face_match_threshold,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def write(
    hub,
    ctx,
    request_route: str,
    request_token: str,
    body: bytes = None,
    status_code: int = None,
    error_code: str = None,
    error_message: str = None,
    accept_ranges: str = None,
    cache_control: str = None,
    content_disposition: str = None,
    content_encoding: str = None,
    content_language: str = None,
    content_length: int = None,
    content_range: str = None,
    content_type: str = None,
    delete_marker: bool = None,
    e_tag: str = None,
    expires: str = None,
    expiration: str = None,
    last_modified: str = None,
    missing_meta: int = None,
    metadata: Dict = None,
    object_lock_mode: str = None,
    object_lock_legal_hold_status: str = None,
    object_lock_retain_until_date: str = None,
    parts_count: int = None,
    replication_status: str = None,
    request_charged: str = None,
    restore: str = None,
    server_side_encryption: str = None,
    sse_customer_algorithm: str = None,
    ssekms_key_id: str = None,
    sse_customer_key_md5: str = None,
    storage_class: str = None,
    tag_count: int = None,
    version_id: str = None,
    bucket_key_enabled: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Passes transformed objects to a GetObject operation when using Object Lambda Access Points. For information about Object Lambda Access Points, see Transforming objects with Object Lambda Access Points in the Amazon S3 User Guide. This operation supports metadata that can be returned by GetObject, in addition to RequestRoute, RequestToken, StatusCode, ErrorCode, and ErrorMessage. The GetObject response metadata is supported so that the WriteGetObjectResponse caller, typically an AWS Lambda function, can provide the same metadata when it internally invokes GetObject. When WriteGetObjectResponse is called by a customer-owned Lambda function, the metadata returned to the end user GetObject call might differ from what Amazon S3 would normally return. AWS provides some prebuilt Lambda functions that you can use with S3 Object Lambda to detect and redact personally identifiable information (PII) and decompress S3 objects. These Lambda functions are available in the AWS Serverless Application Repository, and can be selected through the AWS Management Console when you create your Object Lambda Access Point. Example 1: PII Access Control - This Lambda function uses Amazon Comprehend, a natural language processing (NLP) service using machine learning to find insights and relationships in text. It automatically detects personally identifiable information (PII) such as names, addresses, dates, credit card numbers, and social security numbers from documents in your Amazon S3 bucket.  Example 2: PII Redaction - This Lambda function uses Amazon Comprehend, a natural language processing (NLP) service using machine learning to find insights and relationships in text. It automatically redacts personally identifiable information (PII) such as names, addresses, dates, credit card numbers, and social security numbers from documents in your Amazon S3 bucket.  Example 3: Decompression - The Lambda function S3ObjectLambdaDecompression, is equipped to decompress objects stored in S3 in one of six compressed file formats including bzip2, gzip, snappy, zlib, zstandard and ZIP.  For information on how to view and use these functions, see Using AWS built Lambda functions in the Amazon S3 User Guide.

    Args:
        request_route(str): Route prefix to the HTTP URL generated.
        request_token(str): A single use encrypted token that maps WriteGetObjectResponse to the end user GetObject request.
        body(bytes, optional): The object data. Defaults to None.
        status_code(int, optional): The integer status code for an HTTP response of a corresponding GetObject request.  Status Codes     200 - OK     206 - Partial Content     304 - Not Modified     400 - Bad Request     401 - Unauthorized     403 - Forbidden     404 - Not Found     405 - Method Not Allowed     409 - Conflict     411 - Length Required     412 - Precondition Failed     416 - Range Not Satisfiable     500 - Internal Server Error     503 - Service Unavailable   . Defaults to None.
        error_code(str, optional): A string that uniquely identifies an error condition. Returned in the <Code> tag of the error XML response for a corresponding GetObject call. Cannot be used with a successful StatusCode header or when the transformed object is provided in the body. All error codes from S3 are sentence-cased. Regex value is "^[A-Z][a-zA-Z]+$". Defaults to None.
        error_message(str, optional): Contains a generic description of the error condition. Returned in the <Message> tag of the error XML response for a corresponding GetObject call. Cannot be used with a successful StatusCode header or when the transformed object is provided in body. Defaults to None.
        accept_ranges(str, optional): Indicates that a range of bytes was specified. Defaults to None.
        cache_control(str, optional): Specifies caching behavior along the request/reply chain. Defaults to None.
        content_disposition(str, optional): Specifies presentational information for the object. Defaults to None.
        content_encoding(str, optional): Specifies what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field. Defaults to None.
        content_language(str, optional): The language the content is in. Defaults to None.
        content_length(int, optional): The size of the content body in bytes. Defaults to None.
        content_range(str, optional): The portion of the object returned in the response. Defaults to None.
        content_type(str, optional): A standard MIME type describing the format of the object data. Defaults to None.
        delete_marker(bool, optional): Specifies whether an object stored in Amazon S3 is (true) or is not (false) a delete marker. . Defaults to None.
        e_tag(str, optional): An opaque identifier assigned by a web server to a specific version of a resource found at a URL. . Defaults to None.
        expires(str, optional): The date and time at which the object is no longer cacheable. Defaults to None.
        expiration(str, optional): If object stored in Amazon S3 expiration is configured (see PUT Bucket lifecycle) it includes expiry-date and rule-id key-value pairs providing object expiration information. The value of the rule-id is URL encoded. . Defaults to None.
        last_modified(str, optional): The date and time that the object was last modified. Defaults to None.
        missing_meta(int, optional): Set to the number of metadata entries not returned in x-amz-meta headers. This can happen if you create metadata using an API like SOAP that supports more flexible metadata than the REST API. For example, using SOAP, you can create metadata whose values are not legal HTTP headers. Defaults to None.
        metadata(Dict, optional): A map of metadata to store with the object in S3. Defaults to None.
        object_lock_mode(str, optional): Indicates whether an object stored in Amazon S3 has Object Lock enabled. For more information about S3 Object Lock, see Object Lock. Defaults to None.
        object_lock_legal_hold_status(str, optional): Indicates whether an object stored in Amazon S3 has an active legal hold. Defaults to None.
        object_lock_retain_until_date(str, optional): The date and time when Object Lock is configured to expire. Defaults to None.
        parts_count(int, optional): The count of parts this object has. Defaults to None.
        replication_status(str, optional): Indicates if request involves bucket that is either a source or destination in a Replication rule. For more information about S3 Replication, see Replication. Defaults to None.
        request_charged(str, optional): If present, indicates that the requester was successfully charged for the request. Defaults to None.
        restore(str, optional): Provides information about object restoration operation and expiration time of the restored object copy. Defaults to None.
        server_side_encryption(str, optional):  The server-side encryption algorithm used when storing requested object in Amazon S3 (for example, AES256, aws:kms). Defaults to None.
        sse_customer_algorithm(str, optional): Encryption algorithm used if server-side encryption with a customer-provided encryption key was specified for object stored in Amazon S3. Defaults to None.
        ssekms_key_id(str, optional):  If present, specifies the ID of the AWS Key Management Service (AWS KMS) symmetric customer managed customer master key (CMK) that was used for stored in Amazon S3 object. . Defaults to None.
        sse_customer_key_md5(str, optional):  128-bit MD5 digest of customer-provided encryption key used in Amazon S3 to encrypt data stored in S3. For more information, see Protecting data using server-side encryption with customer-provided encryption keys (SSE-C). Defaults to None.
        storage_class(str, optional):  The class of storage used to store object in Amazon S3. Defaults to None.
        tag_count(int, optional): The number of tags, if any, on the object. Defaults to None.
        version_id(str, optional): An ID used to reference a specific version of the object. Defaults to None.
        bucket_key_enabled(bool, optional):  Indicates whether the object stored in Amazon S3 uses an S3 bucket key for server-side encryption with AWS KMS (SSE-KMS). Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.get_object_response.write(
                ctx, request_route=value, request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.get_object_response.write request_route=value, request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="write_get_object_response",
        op_kwargs={
            "RequestRoute": request_route,
            "RequestToken": request_token,
            "Body": body,
            "StatusCode": status_code,
            "ErrorCode": error_code,
            "ErrorMessage": error_message,
            "AcceptRanges": accept_ranges,
            "CacheControl": cache_control,
            "ContentDisposition": content_disposition,
            "ContentEncoding": content_encoding,
            "ContentLanguage": content_language,
            "ContentLength": content_length,
            "ContentRange": content_range,
            "ContentType": content_type,
            "DeleteMarker": delete_marker,
            "ETag": e_tag,
            "Expires": expires,
            "Expiration": expiration,
            "LastModified": last_modified,
            "MissingMeta": missing_meta,
            "Metadata": metadata,
            "ObjectLockMode": object_lock_mode,
            "ObjectLockLegalHoldStatus": object_lock_legal_hold_status,
            "ObjectLockRetainUntilDate": object_lock_retain_until_date,
            "PartsCount": parts_count,
            "ReplicationStatus": replication_status,
            "RequestCharged": request_charged,
            "Restore": restore,
            "ServerSideEncryption": server_side_encryption,
            "SSECustomerAlgorithm": sse_customer_algorithm,
            "SSEKMSKeyId": ssekms_key_id,
            "SSECustomerKeyMD5": sse_customer_key_md5,
            "StorageClass": storage_class,
            "TagCount": tag_count,
            "VersionId": version_id,
            "BucketKeyEnabled": bucket_key_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, contact_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource policies attached to the specified contact or escalation plan.

    Args:
        contact_arn(str): The Amazon Resource Name (ARN) of the contact or escalation plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.policy.get(ctx, contact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.policy.get contact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="get_contact_policy",
        op_kwargs={"ContactArn": contact_arn},
    )


async def put(hub, ctx, contact_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a resource to the specified contact or escalation plan.

    Args:
        contact_arn(str): The Amazon Resource Name (ARN) of the contact or escalation plan.
        policy(str): Details of the resource policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.policy.put(
                ctx, contact_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.policy.put contact_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="put_contact_policy",
        op_kwargs={"ContactArn": contact_arn, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def export(
    hub,
    ctx,
    name: str,
    inclusive_start_time: str,
    exclusive_end_time: str,
    s3_export_configuration: Dict,
    role_arn: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports journal contents within a date and time range from a ledger into a specified Amazon Simple Storage Service (Amazon S3) bucket. The data is written as files in Amazon Ion format. If the ledger with the given Name doesn't exist, then throws ResourceNotFoundException. If the ledger with the given Name is in CREATING status, then throws ResourcePreconditionNotMetException. You can initiate up to two concurrent journal export requests for each ledger. Beyond this limit, journal export requests throw LimitExceededException.

    Args:
        name(str): The name of the ledger.
        inclusive_start_time(str): The inclusive start date and time for the range of journal contents to export. The InclusiveStartTime must be in ISO 8601 date and time format and in Universal Coordinated Time (UTC). For example: 2019-06-13T21:36:34Z. The InclusiveStartTime must be before ExclusiveEndTime. If you provide an InclusiveStartTime that is before the ledger's CreationDateTime, Amazon QLDB defaults it to the ledger's CreationDateTime.
        exclusive_end_time(str): The exclusive end date and time for the range of journal contents to export. The ExclusiveEndTime must be in ISO 8601 date and time format and in Universal Coordinated Time (UTC). For example: 2019-06-13T21:36:34Z. The ExclusiveEndTime must be less than or equal to the current UTC date and time.
        s3_export_configuration(Dict): The configuration settings of the Amazon S3 bucket destination for your export request.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role that grants QLDB permissions for a journal export job to do the following:   Write objects into your Amazon Simple Storage Service (Amazon S3) bucket.   (Optional) Use your customer master key (CMK) in Key Management Service (KMS) for server-side encryption of your exported data.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.journal.to.s3.export(
                ctx,
                name=value,
                inclusive_start_time=value,
                exclusive_end_time=value,
                s3_export_configuration=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.journal.to.s3.export name=value, inclusive_start_time=value, exclusive_end_time=value, s3_export_configuration=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="export_journal_to_s3",
        op_kwargs={
            "Name": name,
            "InclusiveStartTime": inclusive_start_time,
            "ExclusiveEndTime": exclusive_end_time,
            "S3ExportConfiguration": s3_export_configuration,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(hub, ctx, certificate_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to an ACM certificate. Tags are labels that you can use to identify and organize your Amazon Web Services resources. Each tag consists of a key and an optional value. You specify the certificate on input by its Amazon Resource Name (ARN). You specify the tag by using a key-value pair.  You can apply a tag to just one certificate if you want to identify a specific characteristic of that certificate, or you can apply the same tag to multiple certificates if you want to filter for a common relationship among those certificates. Similarly, you can apply the same tag to multiple resources if you want to specify a relationship among those resources. For example, you can add the same tag to an ACM certificate and an Elastic Load Balancing load balancer to indicate that they are both used by the same website. For more information, see Tagging ACM certificates.  To remove one or more tags, use the RemoveTagsFromCertificate action. To view all of the tags that have been applied to the certificate, use the ListTagsForCertificate action.

    Args:
        certificate_arn(str): String that contains the ARN of the ACM certificate to which the tag is to be applied. This must be of the form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).
        tags(List): The key-value pair that defines the tag. The tag value is optional.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.tags.to_certificate.add(
                ctx, certificate_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.tags.to_certificate.add certificate_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="add_tags_to_certificate",
        op_kwargs={"CertificateArn": certificate_arn, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, document: str, comment: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a traffic policy, which you use to create multiple DNS resource record sets for one domain name (such as example.com) or one subdomain name (such as www.example.com).

    Args:
        name(str): The name of the traffic policy.
        document(str): The definition of this traffic policy in JSON format. For more information, see Traffic Policy Document Format.
        comment(str, optional): (Optional) Any comments that you want to include about the traffic policy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.init.create(
                ctx, name=value, document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.init.create name=value, document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_traffic_policy",
        op_kwargs={"Name": name, "Document": document, "Comment": comment},
    )


async def delete(hub, ctx, id_: str, version: int) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a traffic policy. When you delete a traffic policy, Route 53 sets a flag on the policy to indicate that it has been deleted. However, Route 53 never fully deletes the traffic policy. Note the following:   Deleted traffic policies aren't listed if you run ListTrafficPolicies.    There's no way to get a list of deleted policies.   If you retain the ID of the policy, you can get information about the policy, including the traffic policy document, by running GetTrafficPolicy.

    Args:
        id_(str): The ID of the traffic policy that you want to delete.
        version(int): The version number of the traffic policy that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.init.delete(
                ctx, id_=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.init.delete id_=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_traffic_policy",
        op_kwargs={"Id": id_, "Version": version},
    )


async def get(hub, ctx, id_: str, version: int) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specific traffic policy version. For information about how of deleting a traffic policy affects the response from GetTrafficPolicy, see DeleteTrafficPolicy.

    Args:
        id_(str): The ID of the traffic policy that you want to get information about.
        version(int): The version number of the traffic policy that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.init.get(ctx, id_=value, version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.init.get id_=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_traffic_policy",
        op_kwargs={"Id": id_, "Version": version},
    )


async def list_all(
    hub, ctx, traffic_policy_id_marker: str = None, max_items: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the latest version for every traffic policy that is associated with the current account. Policies are listed in the order that they were created in.  For information about how of deleting a traffic policy affects the response from ListTrafficPolicies, see DeleteTrafficPolicy.

    Args:
        traffic_policy_id_marker(str, optional): (Conditional) For your first request to ListTrafficPolicies, don't include the TrafficPolicyIdMarker parameter. If you have more traffic policies than the value of MaxItems, ListTrafficPolicies returns only the first MaxItems traffic policies. To get the next group of policies, submit another request to ListTrafficPolicies. For the value of TrafficPolicyIdMarker, specify the value of TrafficPolicyIdMarker that was returned in the previous response. Defaults to None.
        max_items(str, optional): (Optional) The maximum number of traffic policies that you want Amazon Route 53 to return in response to this request. If you have more than MaxItems traffic policies, the value of IsTruncated in the response is true, and the value of TrafficPolicyIdMarker is the ID of the first traffic policy that Route 53 will return if you submit another request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_traffic_policies",
        op_kwargs={
            "TrafficPolicyIdMarker": traffic_policy_id_marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, server_certificate_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified server certificate. For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic also includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM.   If you are using a server certificate with Elastic Load Balancing, deleting the certificate could have implications for your application. If Elastic Load Balancing doesn't detect the deletion of bound certificates, it may continue to use the certificates. This could cause Elastic Load Balancing to stop accepting traffic. We recommend that you remove the reference to the certificate from Elastic Load Balancing before using this command to delete the certificate. For more information, see DeleteLoadBalancerListeners in the Elastic Load Balancing API Reference.

    Args:
        server_certificate_name(str): The name of the server certificate you want to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.delete(
                ctx, server_certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.delete server_certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_server_certificate",
        op_kwargs={"ServerCertificateName": server_certificate_name},
    )


async def get(hub, ctx, server_certificate_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified server certificate stored in IAM. For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM.

    Args:
        server_certificate_name(str): The name of the server certificate you want to retrieve information about. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.get(
                ctx, server_certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.get server_certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_server_certificate",
        op_kwargs={"ServerCertificateName": server_certificate_name},
    )


async def list_all(
    hub, ctx, path_prefix: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the server certificates stored in IAM that have the specified path prefix. If none exist, the operation returns an empty list.  You can paginate the results using the MaxItems and Marker parameters. For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic also includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM.  IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a servercertificate, see GetServerCertificate.

    Args:
        path_prefix(str, optional):  The path prefix for filtering the results. For example: /company/servercerts would get all server certificates for which the path starts with /company/servercerts. This parameter is optional. If it is not included, it defaults to a slash (/), listing all server certificates. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_server_certificates",
        op_kwargs={"PathPrefix": path_prefix, "Marker": marker, "MaxItems": max_items},
    )


async def tag(hub, ctx, server_certificate_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to an IAM server certificate. If a tag with the same key name already exists, then that tag is overwritten with the new value.  For certificates in a Region supported by Certificate Manager (ACM), we recommend that you don't use IAM server certificates. Instead, use ACM to provision, manage, and deploy your server certificates. For more information about IAM server certificates, Working with server certificates in the IAM User Guide.  A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:    Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.     Access control - Include tags in IAM user-based and resource-based policies. You can use tags to restrict access to only a server certificate that has a specified tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.    Cost allocation - Use tags to help track which individuals and teams are using which Amazon Web Services resources.      If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. For more information about tagging, see Tagging IAM resources in the IAM User Guide.   Amazon Web Services always interprets the tag Value as a single string. If you need to store an array, you can store comma-separated values in the string. However, you must interpret the value in your code.

    Args:
        server_certificate_name(str): The name of the IAM server certificate to which you want to add tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List): The list of tags that you want to attach to the IAM server certificate. Each tag consists of a key name and an associated value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.tag(
                ctx, server_certificate_name=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.tag server_certificate_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="tag_server_certificate",
        op_kwargs={"ServerCertificateName": server_certificate_name, "Tags": tags},
    )


async def untag(hub, ctx, server_certificate_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the IAM server certificate. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  For certificates in a Region supported by Certificate Manager (ACM), we recommend that you don't use IAM server certificates. Instead, use ACM to provision, manage, and deploy your server certificates. For more information about IAM server certificates, Working with server certificates in the IAM User Guide.

    Args:
        server_certificate_name(str): The name of the IAM server certificate from which you want to remove tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tag_keys(List): A list of key names as a simple array of strings. The tags with matching keys are removed from the specified IAM server certificate.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.untag(
                ctx, server_certificate_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.untag server_certificate_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="untag_server_certificate",
        op_kwargs={
            "ServerCertificateName": server_certificate_name,
            "TagKeys": tag_keys,
        },
    )


async def update(
    hub,
    ctx,
    server_certificate_name: str,
    new_path: str = None,
    new_server_certificate_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the name and/or the path of the specified server certificate stored in IAM. For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic also includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM.  You should understand the implications of changing a server certificate's path or name. For more information, see Renaming a server certificate in the IAM User Guide.   The person making the request (the principal), must have permission to change the server certificate with the old name and the new name. For example, to change the certificate named ProductionCert to ProdCert, the principal must have a policy that allows them to update both certificates. If the principal has permission to update the ProductionCert group, but not the ProdCert certificate, then the update fails. For more information about permissions, see Access management in the IAM User Guide.

    Args:
        server_certificate_name(str): The name of the server certificate that you want to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        new_path(str, optional): The new path for the server certificate. Include this only if you are updating the server certificate's path. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        new_server_certificate_name(str, optional): The new name for the server certificate. Include this only if you are updating the server certificate's name. The name of the certificate cannot contain any spaces. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.update(
                ctx, server_certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.update server_certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_server_certificate",
        op_kwargs={
            "ServerCertificateName": server_certificate_name,
            "NewPath": new_path,
            "NewServerCertificateName": new_server_certificate_name,
        },
    )


async def upload(
    hub,
    ctx,
    server_certificate_name: str,
    certificate_body: str,
    private_key: str,
    path: str = None,
    certificate_chain: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a server certificate entity for the account. The server certificate entity includes a public key certificate, a private key, and an optional certificate chain, which should all be PEM-encoded. We recommend that you use Certificate Manager to provision, manage, and deploy your server certificates. With ACM you can request a certificate, deploy it to Amazon Web Services resources, and let ACM handle certificate renewals for you. Certificates provided by ACM are free. For more information about using ACM, see the Certificate Manager User Guide. For more information about working with server certificates, see Working with server certificates in the IAM User Guide. This topic includes a list of Amazon Web Services services that can use the server certificates that you manage with IAM. For information about the number of server certificates you can upload, see IAM and STS quotas in the IAM User Guide.  Because the body of the public key certificate, private key, and the certificate chain can be large, you should use POST rather than GET when calling UploadServerCertificate. For information about setting up signatures and authorization through the API, see Signing Amazon Web Services API requests in the Amazon Web Services General Reference. For general information about using the Query API with IAM, see Calling the API by making HTTP query requests in the IAM User Guide.

    Args:
        path(str, optional): The path for the server certificate. For more information about paths, see IAM identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.   If you are uploading a server certificate specifically for use with Amazon CloudFront distributions, you must specify a path using the path parameter. The path must begin with /cloudfront and must include a trailing slash (for example, /cloudfront/test/). . Defaults to None.
        server_certificate_name(str): The name for the server certificate. Do not include the path in this value. The name of the certificate cannot contain any spaces. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        certificate_body(str): The contents of the public key certificate in PEM-encoded format. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
        private_key(str): The contents of the private key in PEM-encoded format. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
        certificate_chain(str, optional): The contents of the certificate chain. This is typically a concatenation of the PEM-encoded public key certificates of the chain. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  . Defaults to None.
        tags(List, optional): A list of tags that you want to attach to the new IAM server certificate resource. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.server_certificate.init.upload(
                ctx, server_certificate_name=value, certificate_body=value, private_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.server_certificate.init.upload server_certificate_name=value, certificate_body=value, private_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="upload_server_certificate",
        op_kwargs={
            "Path": path,
            "ServerCertificateName": server_certificate_name,
            "CertificateBody": certificate_body,
            "PrivateKey": private_key,
            "CertificateChain": certificate_chain,
            "Tags": tags,
        },
    )
